<?php

/**
 * @copyright Metaways Infosystems GmbH, 2011
 * @license LGPLv3, http://opensource.org/licenses/LGPL-3.0
 * @copyright Aimeos (aimeos.org), 2015
 */


namespace Aimeos\MShop\Order\Item\Base\Service;


/**
 * Test class for \Aimeos\MShop\Order\Item\Base\Service\Standard.
 * Generated by Thorsten Stark on 2010-04-09.
 */
class StandardTest extends \PHPUnit_Framework_TestCase
{
	private $object;
	private $values;
	private $price;
	private $attribute = array();


	protected function setUp()
	{
		$this->price = \Aimeos\MShop\Price\Manager\Factory::createManager( \TestHelperMShop::getContext() )->createItem();

		$attrValues = array(
			'order.base.service.attribute.id' => 3,
			'order.base.service.attribute.siteid' => 99,
			'order.base.service.attribute.parentid' => 42,
			'order.base.service.attribute.name' => 'UnitName',
			'order.base.service.attribute.type' => 'default',
			'order.base.service.attribute.code' => 'UnitCode',
			'order.base.service.attribute.value' => 'UnitValue',
			'order.base.service.attribute.mtime' => '2020-12-31 23:59:59',
			'order.base.service.attribute.ctime' => '2011-01-01 00:00:01',
			'order.base.service.attribute.editor' => 'unitTestUser'
		);

		$this->attribute = array( 'UnitCode' => new \Aimeos\MShop\Order\Item\Base\Service\Attribute\Standard( $attrValues ) );

		$this->values = array(
			'order.base.service.id' => 1,
			'order.base.service.siteid' => 99,
			'order.base.service.serviceid' => 'ServiceID',
			'order.base.service.baseid' => 42,
			'order.base.service.code' => 'UnitCode',
			'order.base.service.name' => 'UnitName',
			'order.base.service.mediaurl' => 'Url for test',
			'order.base.service.type' => 'payment',
			'order.base.service.mtime' => '2012-01-01 00:00:01',
			'order.base.service.ctime' => '2011-01-01 00:00:01',
			'order.base.service.editor' => 'unitTestUser'
		);

		$this->object = new \Aimeos\MShop\Order\Item\Base\Service\Standard( $this->price, $this->values, $this->attribute );
	}

	protected function tearDown()
	{
		unset( $this->object );
	}

	public function testGetId()
	{
		$this->assertEquals( 1, $this->object->getId() );
	}

	public function testSetId()
	{
		$return = $this->object->setId( null );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( null, $this->object->getId() );
		$this->assertTrue( $this->object->isModified() );

		$return = $this->object->setId( 5 );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( 5, $this->object->getId() );
		$this->assertFalse( $this->object->isModified() );

		$this->setExpectedException( '\\Aimeos\\MShop\\Exception' );
		$this->object->setId( 6 );
	}

	public function testSetId2()
	{
		$this->setExpectedException( '\\Aimeos\\MShop\\Exception' );
		$this->object->setId( 'test' );
	}

	public function testGetSiteId()
	{
		$this->assertEquals( 99, $this->object->getSiteId() );
	}

	public function testGetBaseId()
	{
		$this->assertEquals( 42, $this->object->getBaseId() );
	}

	public function testSetBaseId()
	{
		$return = $this->object->setBaseId( 111 );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( 111, $this->object->getBaseId() );
		$this->assertTrue( $this->object->isModified() );
	}

	public function testSetBaseIdReset()
	{
		$return = $this->object->setBaseId( null );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( null, $this->object->getBaseId() );
		$this->assertTrue( $this->object->isModified() );
	}

	public function testGetServiceId()
	{
		$this->assertEquals( 'ServiceID', $this->object->getServiceId() );
	}

	public function testSetServiceId()
	{
		$return = $this->object->setServiceId( 'testServiceID' );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( 'testServiceID', $this->object->getServiceId() );
		$this->assertTrue( $this->object->isModified() );
	}

	public function testGetCode()
	{
		$this->assertEquals( 'UnitCode', $this->object->getCode() );
	}

	public function testSetCode()
	{
		$return = $this->object->setCode( 'testCode' );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( 'testCode', $this->object->getCode() );
		$this->assertTrue( $this->object->isModified() );
	}

	public function testGetName()
	{
		$this->assertEquals( 'UnitName', $this->object->getName() );
	}

	public function testSetName()
	{
		$return = $this->object->setName( 'testName' );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( 'testName', $this->object->getName() );
		$this->assertTrue( $this->object->isModified() );
	}

	public function testGetMediaUrl()
	{
		$this->assertEquals( 'Url for test', $this->object->getMediaUrl() );
	}

	public function testSetMediaUrl()
	{
		$return = $this->object->setMediaUrl( 'testUrl' );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( 'testUrl', $this->object->getMediaUrl() );
		$this->assertTrue( $this->object->isModified() );
	}

	public function testGetType()
	{
		$this->assertEquals( 'payment', $this->object->getType() );
	}

	public function testSetType()
	{
		$return = $this->object->setType( 'delivery' );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( 'delivery', $this->object->getType() );
		$this->assertTrue( $this->object->isModified() );
	}

	public function testGetPrice()
	{
		$this->assertSame( $this->price, $this->object->getPrice() );
	}

	public function testSetPrice()
	{
		$this->price->setCosts( '5.00' );
		$return = $this->object->setPrice( $this->price );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertFalse( $this->object->isModified() );
		$this->assertSame( $this->price, $this->object->getPrice() );
	}

	public function testGetAttribute()
	{
		$manager = \Aimeos\MShop\Order\Manager\Factory::createManager( \TestHelperMShop::getContext() );
		$attManager = $manager->getSubManager( 'base' )->getSubManager( 'service' )->getSubManager( 'attribute' );

		$attrItem001 = $attManager->createItem();
		$attrItem001->setCode( 'code_001' );
		$attrItem001->setValue( 'value_001' );

		$attrItem002 = $attManager->createItem();
		$attrItem002->setCode( 'code_002' );
		$attrItem002->setType( 'test_002' );
		$attrItem002->setValue( 'value_002' );

		$this->object->setAttributes( array( $attrItem001, $attrItem002 ) );

		$result = $this->object->getAttribute( 'code_001' );
		$this->assertEquals( 'value_001', $result );

		$result = $this->object->getAttribute( 'code_002', 'test_002' );
		$this->assertEquals( 'value_002', $result );

		$result = $this->object->getAttribute( 'code_002' );
		$this->assertEquals( null, $result );

		$result = $this->object->getAttribute( 'code_003' );
		$this->assertEquals( null, $result );

		$this->object->setAttributes( array() );

		$result = $this->object->getAttribute( 'code_001' );
		$this->assertEquals( null, $result );
	}

	public function testGetAttributeItem()
	{
		$manager = \Aimeos\MShop\Order\Manager\Factory::createManager( \TestHelperMShop::getContext() );
		$attManager = $manager->getSubManager( 'base' )->getSubManager( 'service' )->getSubManager( 'attribute' );

		$attrItem001 = $attManager->createItem();
		$attrItem001->setCode( 'code_001' );
		$attrItem001->setValue( 'value_001' );

		$attrItem002 = $attManager->createItem();
		$attrItem002->setCode( 'code_002' );
		$attrItem002->setType( 'test_002' );
		$attrItem002->setValue( 'value_002' );

		$this->object->setAttributes( array( $attrItem001, $attrItem002 ) );

		$result = $this->object->getAttributeItem( 'code_001' );
		$this->assertEquals( 'value_001', $result->getValue() );

		$result = $this->object->getAttributeItem( 'code_002', 'test_002' );
		$this->assertEquals( 'value_002', $result->getValue() );

		$result = $this->object->getAttributeItem( 'code_002' );
		$this->assertEquals( null, $result );

		$result = $this->object->getAttributeItem( 'code_003' );
		$this->assertEquals( null, $result );

		$this->object->setAttributes( array() );

		$result = $this->object->getAttributeItem( 'code_001' );
		$this->assertEquals( null, $result );
	}

	public function testGetAttributes()
	{
		$this->assertEquals( $this->attribute, $this->object->getAttributes() );
	}

	public function testGetAttributesByType()
	{
		$this->assertEquals( $this->attribute, $this->object->getAttributes( 'default' ) );
	}

	public function testGetAttributesInvalidType()
	{
		$this->assertEquals( array(), $this->object->getAttributes( 'invalid' ) );
	}

	public function testSetAttributeItem()
	{
		$manager = \Aimeos\MShop\Order\Manager\Factory::createManager( \TestHelperMShop::getContext() );
		$attManager = $manager->getSubManager( 'base' )->getSubManager( 'service' )->getSubManager( 'attribute' );

		$item = $attManager->createItem();
		$item->setCode( 'test_code' );
		$item->setType( 'test_type' );
		$item->setValue( 'test_value' );

		$return = $this->object->setAttributeItem( $item );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( 'test_value', $this->object->getAttributeItem( 'test_code', 'test_type' )->getValue() );
		$this->assertTrue( $this->object->isModified() );

		$item = $attManager->createItem();
		$item->setCode( 'test_code' );
		$item->setType( 'test_type' );
		$item->setValue( 'test_value2' );

		$return = $this->object->setAttributeItem( $item );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( 'test_value2', $this->object->getAttributeItem( 'test_code', 'test_type' )->getValue() );
		$this->assertTrue( $this->object->isModified() );
	}

	public function testSetAttributes()
	{
		$manager = \Aimeos\MShop\Order\Manager\Factory::createManager( \TestHelperMShop::getContext() );
		$attManager = $manager->getSubManager( 'base' )->getSubManager( 'service' )->getSubManager( 'attribute' );

		$list = array(
			$attManager->createItem(),
			$attManager->createItem(),
		);

		$return = $this->object->setAttributes( $list );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( $list, $this->object->getAttributes() );
		$this->assertTrue( $this->object->isModified() );
	}

	public function testGetTimeModified()
	{
		$this->assertEquals( '2012-01-01 00:00:01', $this->object->getTimeModified() );
	}

	public function testGetTimeCreated()
	{
		$this->assertEquals( '2011-01-01 00:00:01', $this->object->getTimeCreated() );
	}

	public function testGetEditor()
	{
		$this->assertEquals( 'unitTestUser', $this->object->getEditor() );
	}


	public function testFromArray()
	{
		$item = new \Aimeos\MShop\Order\Item\Base\Service\Standard( new \Aimeos\MShop\Price\Item\Standard() );

		$list = array(
			'order.base.service.id' => 1,
			'order.base.service.baseid' => 2,
			'order.base.service.serviceid' => 3,
			'order.base.service.code' => 'test',
			'order.base.service.name' => 'test item',
			'order.base.service.type' => 'delivery',
		);

		$unknown = $item->fromArray( $list );

		$this->assertEquals( array(), $unknown );

		$this->assertEquals( $list['order.base.service.id'], $item->getId() );
		$this->assertEquals( $list['order.base.service.baseid'], $item->getBaseId() );
		$this->assertEquals( $list['order.base.service.serviceid'], $item->getServiceId() );
		$this->assertEquals( $list['order.base.service.code'], $item->getCode() );
		$this->assertEquals( $list['order.base.service.name'], $item->getName() );
		$this->assertEquals( $list['order.base.service.type'], $item->getType() );
	}


	public function testToArray()
	{
		$arrayObject = $this->object->toArray();
		$this->assertEquals( count( $this->values ) + 4, count( $arrayObject ) );

		$this->assertEquals( $this->object->getId(), $arrayObject['order.base.service.id'] );
		$this->assertEquals( $this->object->getBaseId(), $arrayObject['order.base.service.baseid'] );
		$this->assertEquals( $this->object->getServiceId(), $arrayObject['order.base.service.serviceid'] );
		$this->assertEquals( $this->object->getCode(), $arrayObject['order.base.service.code'] );
		$this->assertEquals( $this->object->getName(), $arrayObject['order.base.service.name'] );
		$this->assertEquals( $this->object->getType(), $arrayObject['order.base.service.type'] );
		$this->assertEquals( $this->object->getTimeModified(), $arrayObject['order.base.service.mtime'] );
		$this->assertEquals( $this->object->getTimeCreated(), $arrayObject['order.base.service.ctime'] );
		$this->assertEquals( $this->object->getTimeModified(), $arrayObject['order.base.service.mtime'] );
		$this->assertEquals( $this->object->getEditor(), $arrayObject['order.base.service.editor'] );

		$price = $this->object->getPrice();
		$this->assertEquals( $price->getValue(), $arrayObject['order.base.service.price'] );
		$this->assertEquals( $price->getCosts(), $arrayObject['order.base.service.costs'] );
		$this->assertEquals( $price->getRebate(), $arrayObject['order.base.service.rebate'] );
		$this->assertEquals( $price->getTaxRate(), $arrayObject['order.base.service.taxrate'] );
	}

	public function testIsModified()
	{
		$this->assertFalse( $this->object->isModified() );
	}


	public function testGetResourceType()
	{
		$this->assertEquals( 'order/base/service', $this->object->getResourceType() );
	}


	public function testCopyFrom()
	{
		$serviceCopy = new \Aimeos\MShop\Order\Item\Base\Service\Standard( $this->price );

		$manager = \Aimeos\MShop\Service\Manager\Factory::createManager( \TestHelperMShop::getContext() );

		$search = $manager->createSearch();
		$search->setConditions( $search->compare( '==', 'service.provider', 'Standard' ) );
		$services = $manager->searchItems( $search );

		if( ( $service = reset( $services ) ) === false ) {
			throw new \Exception( 'No service found' );
		}

		$return = $serviceCopy->copyFrom( $service );

		$this->assertInstanceOf( '\Aimeos\MShop\Order\Item\Base\Service\Iface', $return );
		$this->assertEquals( 'unitcode', $serviceCopy->getCode() );
		$this->assertEquals( 'unitlabel', $serviceCopy->getName() );
		$this->assertEquals( 'delivery', $serviceCopy->getType() );
		$this->assertEquals( '', $serviceCopy->getMediaUrl() );

		$this->assertTrue( $serviceCopy->isModified() );
	}
}
